@@ -46,15 +46,11 @@
 #include <gst/pbutils/missing-plugins.h>
 #include <gst/tag/tag.h>
 
-#include "brasero-metadata.h"
 #include "brasero-misc.h"
+#include "brasero-metadata.h"
 
-#define BRASERO_METADATA_INITIAL_STATE		GST_STATE_PAUSED
-
-
-G_DEFINE_TYPE(BraseroMetadata, brasero_metadata, G_TYPE_OBJECT)
-
-#define BRASERO_METADATA_SILENCE_INTERVAL		100000000
+#define BRASERO_METADATA_SILENCE_INTERVAL		100000000LL
+#define BRASERO_METADATA_INITIAL_STATE			GST_STATE_PAUSED
 
 struct BraseroMetadataPrivate {
 	GstElement *pipeline;
@@ -89,6 +85,9 @@ struct BraseroMetadataPrivate {
 
 	gint listeners;
 
+	BraseroMetadataGetXidCb xid_callback;
+	gpointer xid_user_data;
+
 	guint started:1;
 	guint moved_forward:1;
 	guint prev_level_mes:1;
@@ -115,11 +114,38 @@ static guint brasero_metadata_signals [LAST_SIGNAL] = { 0 };
 	(!((flags) & BRASERO_METADATA_FLAG_SILENCES) &&				\
 	((flags) & BRASERO_METADATA_FLAG_FAST))
 
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE (BraseroMetadata, brasero_metadata, G_TYPE_OBJECT)
 
 static GSList *downloading = NULL;
 static GSList *downloaded = NULL;
 
+static gboolean
+brasero_metadata_completed (BraseroMetadata *self);
+
+static int
+brasero_metadata_get_xid (BraseroMetadata *metadata)
+{
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (metadata);
+	if (!priv->xid_callback)
+		return 0;
+
+	return priv->xid_callback (priv->xid_user_data);
+}
+
+void
+brasero_metadata_set_get_xid_callback (BraseroMetadata *metadata,
+                                       BraseroMetadataGetXidCb callback,
+                                       gpointer user_data)
+{
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (metadata);
+	priv->xid_callback = callback;
+	priv->xid_user_data = user_data;
+}
+
 struct _BraseroMetadataGstDownload {
 	gchar *detail;
 
@@ -187,6 +213,9 @@ brasero_metadata_info_copy (BraseroMetadataInfo *dest,
 	if (!dest || !src)
 		return;
 
+	dest->has_dts = src->has_dts;
+	dest->rate = src->rate;
+	dest->channels = src->channels;
 	dest->isrc = src->isrc;
 	dest->len = src->len;
 	dest->is_seekable = src->is_seekable;
@@ -230,7 +259,6 @@ brasero_metadata_info_copy (BraseroMetadataInfo *dest,
 
 		dest->silences = g_slist_append (dest->silences, copy);
 	}
-
 }
 
 static void
@@ -396,6 +424,259 @@ brasero_metadata_cancel (BraseroMetadata *self)
 		priv->error = NULL;
 	}
 }
+static void
+brasero_metadata_install_plugins_add_downloaded (GSList *downloads)
+{
+	GSList *iter;
+
+	for (iter = downloads; iter; iter = iter->next) {
+		BraseroMetadataGstDownload *download;
+
+		download = iter->data;
+		downloaded = g_slist_prepend (downloaded, download->detail);
+		download->detail = NULL;
+	}
+}
+
+static void
+brasero_metadata_install_plugins_free_data (GSList *downloads)
+{
+	GSList *iter;
+
+	for (iter = downloads; iter; iter = iter->next) {
+		BraseroMetadataGstDownload *download;
+		GSList *meta;
+
+		download = iter->data;
+		if (download->detail)
+			g_free (download->detail);
+
+		for (meta = download->objects; meta; meta = meta->next) {
+			BraseroMetadataPrivate *priv;
+
+			priv = BRASERO_METADATA_PRIVATE (meta->data);
+			priv->downloads = g_slist_remove (priv->downloads, download);
+		}
+		g_slist_free (download->objects);
+
+		downloading = g_slist_remove (downloading, download);
+		g_free (download);
+	}
+
+	g_slist_free (downloads);
+}
+
+static void
+brasero_metadata_install_plugins_success (BraseroMetadataGstDownload *download)
+{
+	GSList *iter;
+
+	for (iter = download->objects; iter; iter = iter->next) {
+		BraseroMetadataPrivate *priv;
+
+		priv = BRASERO_METADATA_PRIVATE (iter->data);
+
+		if (priv->error) {
+			/* free previously saved error message */
+			g_error_free (priv->error);
+			priv->error = NULL;
+		}
+
+		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_NULL);
+		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_PLAYING);
+	}
+}
+
+static void
+brasero_metadata_install_plugins_abort (BraseroMetadataGstDownload *download)
+{
+	GSList *iter;
+	GSList *next;
+
+	for (iter = download->objects; iter; iter = next) {
+		BraseroMetadataPrivate *priv;
+
+		next = iter->next;
+
+		priv = BRASERO_METADATA_PRIVATE (iter->data);
+
+		if (priv->error) {
+			g_error_free (priv->error);
+			priv->error = NULL;
+		}
+
+		brasero_metadata_completed (BRASERO_METADATA (iter->data));
+	}
+}
+
+static void
+brasero_metadata_install_plugins_completed (BraseroMetadataGstDownload *download)
+{
+	GSList *iter;
+	GSList *next;
+
+	for (iter = download->objects; iter; iter = next) {
+		next = iter->next;
+		brasero_metadata_completed (BRASERO_METADATA (iter->data));
+	}
+}
+
+static void
+brasero_metadata_install_plugins_result (GstInstallPluginsReturn res,
+					 gpointer data)
+{
+	GSList *downloads = data;
+	GSList *iter;
+
+	switch (res) {
+	case GST_INSTALL_PLUGINS_PARTIAL_SUCCESS:
+	case GST_INSTALL_PLUGINS_SUCCESS:
+		brasero_metadata_install_plugins_add_downloaded (downloads);
+
+		/* force gst to update plugin list */
+		gst_update_registry ();
+
+		/* restart metadata search */
+		for (iter = downloads; iter; iter = iter->next) {
+			BraseroMetadataGstDownload *download;
+
+			download = iter->data;
+			brasero_metadata_install_plugins_success (download);
+		}
+		break;
+
+	case GST_INSTALL_PLUGINS_NOT_FOUND:
+		brasero_metadata_install_plugins_add_downloaded (downloads);
+
+		/* stop everything */
+		for (iter = downloads; iter; iter = iter->next)
+			brasero_metadata_install_plugins_completed (iter->data);
+		break;
+
+	case GST_INSTALL_PLUGINS_USER_ABORT:
+		brasero_metadata_install_plugins_add_downloaded (downloads);
+
+		/* free previously saved error message */
+		for (iter = downloads; iter; iter = iter->next) {
+			BraseroMetadataGstDownload *download;
+
+			download = iter->data;
+			brasero_metadata_install_plugins_abort (download);
+		}
+		break;
+
+	case GST_INSTALL_PLUGINS_ERROR:
+	case GST_INSTALL_PLUGINS_CRASHED:
+	default:
+		for (iter = downloads; iter; iter = iter->next)
+			brasero_metadata_install_plugins_completed (iter->data);
+
+		break;
+	}
+
+	brasero_metadata_install_plugins_free_data (downloads);
+}
+
+static BraseroMetadataGstDownload *
+brasero_metadata_is_downloading (const gchar *detail)
+{
+	GSList *iter;
+
+	for (iter = downloading; iter; iter = iter->next) {
+		BraseroMetadataGstDownload *download;
+
+		download = iter->data;
+		if (!strcmp (download->detail, detail))
+			return download;
+	}
+
+	return NULL;
+}
+
+static gboolean
+brasero_metadata_install_missing_plugins (BraseroMetadata *self)
+{
+	GstInstallPluginsContext *context;
+	GstInstallPluginsReturn status;
+	BraseroMetadataPrivate *priv;
+	GSList *downloads = NULL;
+	GPtrArray *details;
+	GSList *iter;
+
+	priv = BRASERO_METADATA_PRIVATE (self);
+
+	BRASERO_UTILS_LOG ("Starting to download missing plugins");
+
+	details = g_ptr_array_new ();
+	for (iter = priv->missing_plugins; iter; iter = iter->next) {
+		gchar *detail;
+		BraseroMetadataGstDownload *download;
+
+		/* Check if this plugin:
+		 * - has already been downloaded (whether it was successful or not)
+		 * - is being downloaded
+		 * If so don't do anything. */
+		detail = gst_missing_plugin_message_get_installer_detail (iter->data);
+		gst_mini_object_unref (iter->data);
+
+		download = brasero_metadata_is_downloading (detail);
+		if (download) {
+			download->objects = g_slist_prepend (download->objects, self);
+			g_free (detail);
+			continue;
+		}
+
+		if (g_slist_find_custom (downloaded, detail, (GCompareFunc) strcmp)) {
+			g_free (detail);
+			continue;
+		}
+
+		download = g_new0 (BraseroMetadataGstDownload, 1);
+		download->detail = detail;
+		download->objects = g_slist_prepend (download->objects, self);
+		priv->downloads = g_slist_prepend (priv->downloads, download);
+
+		downloads = g_slist_prepend (downloads, download);
+		downloading = g_slist_prepend (downloading, download);
+
+		g_ptr_array_add (details, detail);
+	}
+
+	g_slist_free (priv->missing_plugins);
+	priv->missing_plugins = NULL;
+
+	if (!details->len) {
+		/* either these plugins were downloaded or are being downloaded */
+		g_ptr_array_free (details, TRUE);
+		if (!priv->downloads)
+			return FALSE;
+
+		return TRUE;
+	}
+
+	g_ptr_array_add (details, NULL);
+
+	/* FIXME: we'd need the main window here to set it modal */
+
+	context = gst_install_plugins_context_new ();
+	gst_install_plugins_context_set_xid (context, brasero_metadata_get_xid (self));
+	status = gst_install_plugins_async ((gchar **) details->pdata,
+					    context,
+					    brasero_metadata_install_plugins_result,
+					    downloads);
+
+	gst_install_plugins_context_free (context);
+	g_ptr_array_free (details, TRUE);
+
+	BRASERO_UTILS_LOG ("Download status %i", status);
+
+	if (status != GST_INSTALL_PLUGINS_STARTED_OK) {
+		brasero_metadata_install_plugins_free_data (downloads);
+		return FALSE;
+	}
+
+	return TRUE;
+}
 
 static gboolean
 brasero_metadata_completed (BraseroMetadata *self)
@@ -408,6 +689,12 @@ brasero_metadata_completed (BraseroMetadata *self)
 		BRASERO_UTILS_LOG ("Operation completed with an error %s", priv->error->message);
 	}
 
+	/* See if we have missing plugins */
+	if (priv->missing_plugins) {
+		if (brasero_metadata_install_missing_plugins (self))
+			return TRUE;
+	}
+
 	/* we send a message only if we haven't got a loop (= async mode) */
 	g_object_ref (self);
 	g_signal_emit (G_OBJECT (self),
@@ -474,8 +761,13 @@ brasero_metadata_is_seekable (BraseroMetadata *self)
 	priv = BRASERO_METADATA_PRIVATE (self);
 
 	priv->info->is_seekable = FALSE;
-	query = gst_query_new_seeking (GST_FORMAT_DEFAULT);
-	if (!gst_element_query (priv->source, query))
+
+	/* NOTE: apparently GST_FORMAT_DEFAULT does not work here */
+	query = gst_query_new_seeking (GST_FORMAT_TIME);
+
+	/* NOTE: it works better now on the pipeline than on the source as we
+	 * used to do */
+	if (!gst_element_query (priv->pipeline, query))
 		goto end;
 
 	gst_query_parse_seeking (query,
@@ -487,6 +779,7 @@ brasero_metadata_is_seekable (BraseroMetadata *self)
 	priv->info->is_seekable = seekable;
 
 end:
+
 	gst_query_unref (query);
 }
 
@@ -533,6 +826,79 @@ brasero_metadata_get_mime_type (BraseroMetadata *self)
 
 	if (!strcmp (mime, "application/x-id3"))
 		priv->info->type = g_strdup ("audio/mpeg");
+	else if (!strcmp (mime, "audio/x-wav")) {
+		GstElement *wavparse = NULL;
+		gpointer element = NULL;
+		GstIteratorResult res;
+		GstIterator *iter;
+
+		priv->info->type = g_strdup (mime);
+
+		/* make sure it doesn't have dts inside */
+		iter = gst_bin_iterate_recurse (GST_BIN (priv->decode));
+
+		res = gst_iterator_next (iter, &element);
+		while (res == GST_ITERATOR_OK) {
+			gchar *name;
+
+			name = gst_object_get_name (GST_OBJECT (element));
+			if (name) {
+				if (!strncmp (name, "wavparse", 8)) {
+					wavparse = element;
+					g_free (name);
+					break;
+				}
+				g_free (name);
+			}
+
+			gst_object_unref (element);
+			element = NULL;
+
+			res = gst_iterator_next (iter, &element);
+		}
+		gst_iterator_free (iter);
+
+		if (wavparse) {
+			GstPad *src_pad;
+
+			iter = gst_element_iterate_src_pads (wavparse);
+
+			res = gst_iterator_next (iter, (gpointer *) &src_pad);
+			while (res == GST_ITERATOR_OK) {
+				GstCaps *src_caps;
+
+				src_caps = gst_pad_get_caps (src_pad);
+				if (src_caps) {
+					GstStructure *structure;
+
+					structure = gst_caps_get_structure (src_caps, 0);
+					if (structure) {
+						const gchar *name;
+
+						name = gst_structure_get_name (structure);
+						priv->info->has_dts = (g_strrstr (name, "audio/x-dts") != NULL);
+						if (priv->info->has_dts) {
+							gst_object_unref (src_pad);
+							gst_caps_unref (src_caps);
+							src_pad = NULL;
+							break;
+						}
+					}
+					gst_caps_unref (src_caps);
+				}
+
+				gst_object_unref (src_pad);
+				src_pad = NULL;
+
+				res = gst_iterator_next (iter,  (gpointer *) &src_pad);
+			}
+
+			gst_iterator_free (iter);
+			gst_object_unref (wavparse);
+		}
+
+		BRASERO_UTILS_LOG ("Wav file has dts: %s", priv->info->has_dts? "yes":"no");
+	}
 	else
 		priv->info->type = g_strdup (mime);
 
@@ -606,8 +972,89 @@ foreach_tag (const GstTagList *list,
 	}
 }
 
+static gboolean
+brasero_metadata_process_element_messages (BraseroMetadata *self,
+					   GstMessage *msg)
+{
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (self);
+
+	/* This is for snapshot function */
+	if (!strcmp (gst_structure_get_name (msg->structure), "preroll-pixbuf")
+	||  !strcmp (gst_structure_get_name (msg->structure), "pixbuf")) {
+		const GValue *value;
+
+		value = gst_structure_get_value (msg->structure, "pixbuf");
+		priv->info->snapshot = g_value_get_object (value);
+		g_object_ref (priv->info->snapshot);
+
+		BRASERO_UTILS_LOG ("Received pixbuf snapshot sink (%p) for %s", priv->info->snapshot, priv->info->uri);
+
+		/* Now we can stop */
+		return brasero_metadata_completed (self);
+	}
+
+	/* here we just want to check if that's a missing codec */
+	if ((priv->flags & BRASERO_METADATA_FLAG_MISSING)
+	&&   gst_is_missing_plugin_message (msg)) {
+		priv->missing_plugins = g_slist_prepend (priv->missing_plugins, gst_message_ref (msg));
+	}
+	else if (!strcmp (gst_structure_get_name (msg->structure), "level")
+	&&   gst_structure_has_field (msg->structure, "peak")) {
+		const GValue *value;
+		const GValue *list;
+		gdouble peak;
+
+		list = gst_structure_get_value (msg->structure, "peak");
+		value = gst_value_list_get_value (list, 0);
+		peak = g_value_get_double (value);
+
+		/* detection of silence */
+		if (peak < -50.0) {
+			gint64 pos = -1;
+			GstFormat format = GST_FORMAT_TIME;
+
+			/* was there a silence last time we check ?
+			 * NOTE: if that's the first signal we receive
+			 * then consider that silence started from 0 */
+			gst_element_query_position (priv->pipeline, &format, &pos);
+			if (pos == -1) {
+				BRASERO_UTILS_LOG ("impossible to retrieve position");
+				return TRUE;
+			}
+
+			if (!priv->silence) {
+				priv->silence = g_new0 (BraseroMetadataSilence, 1);
+				if (priv->prev_level_mes) {
+					priv->silence->start = pos;
+					priv->silence->end = pos;
+				}
+				else {
+					priv->silence->start = 0;
+					priv->silence->end = pos;
+				}
+			}				
+			else
+				priv->silence->end = pos;
+
+			BRASERO_UTILS_LOG ("silence detected at %lli", pos);
+		}
+		else if (priv->silence) {
+			BRASERO_UTILS_LOG ("silence finished");
+
+			priv->info->silences = g_slist_append (priv->info->silences,
+							       priv->silence);
+			priv->silence = NULL;
+		}
+		priv->prev_level_mes = 1;
+	}
+
+	return TRUE;
+}
+
 static void
-brasero_metadata_process_pending_tag_messages (BraseroMetadata *self)
+brasero_metadata_process_pending_messages (BraseroMetadata *self)
 {
 	GstBus *bus;
 	GstMessage *msg;
@@ -616,12 +1063,16 @@ brasero_metadata_process_pending_tag_messages (BraseroMetadata *self)
 	priv = BRASERO_METADATA_PRIVATE (self);
 
 	bus = gst_pipeline_get_bus (GST_PIPELINE (priv->pipeline));
-	while ((msg = gst_bus_pop_filtered (bus, GST_MESSAGE_TAG))) {
+	while ((msg = gst_bus_pop (bus))) {
 		GstTagList *tags = NULL;
 
-		gst_message_parse_tag (msg, &tags);
-		gst_tag_list_foreach (tags, (GstTagForeachFunc) foreach_tag, self);
-		gst_tag_list_free (tags);
+		if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_TAG) {
+			gst_message_parse_tag (msg, &tags);
+			gst_tag_list_foreach (tags, (GstTagForeachFunc) foreach_tag, self);
+			gst_tag_list_free (tags);
+		}
+		else if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_ELEMENT)
+			brasero_metadata_process_element_messages (self, msg);
 
 		gst_message_unref (msg);
 	}
@@ -684,7 +1135,7 @@ brasero_metadata_get_duration (BraseroMetadata *self,
 			BRASERO_GET_BASENAME_FOR_DISPLAY (priv->info->uri, name);
 			priv->error = g_error_new (BRASERO_UTILS_ERROR,
 						   BRASERO_UTILS_ERROR_GENERAL,
-						   _("\"%s\" could not be handled by Gstreamer."),
+						   _("\"%s\" could not be handled by GStreamer."),
 						   name);
 			g_free (name);
 		}
@@ -692,7 +1143,7 @@ brasero_metadata_get_duration (BraseroMetadata *self,
 		return brasero_metadata_completed (self);
 	}
 
-	BRASERO_UTILS_LOG ("found duration %lli for %s", duration, priv->info->uri);
+	BRASERO_UTILS_LOG ("Found duration %lli for %s", duration, priv->info->uri);
 
 	priv->info->len = duration;
 	return brasero_metadata_success (self);
@@ -717,7 +1168,7 @@ brasero_metadata_mp3_bus_messages (GstBus *bus,
 	case GST_MESSAGE_ERROR:
 		/* save the error message */
 		gst_message_parse_error (msg, &error, &debug_string);
-		BRASERO_UTILS_LOG ("Gstreamer error - mp3 - (%s)", debug_string);
+		BRASERO_UTILS_LOG ("GStreamer error - mp3 - (%s)", debug_string);
 		g_free (debug_string);
 		if (!priv->error && error)
 			priv->error = error;
@@ -822,7 +1273,7 @@ brasero_metadata_success_main (BraseroMetadata *self)
 	brasero_metadata_get_mime_type (self);
 
 	/* empty the bus of any pending message */
-	brasero_metadata_process_pending_tag_messages (self);
+	brasero_metadata_process_pending_messages (self);
 
 	/* get the size */
 	if (brasero_metadata_is_mp3 (self)) {
@@ -838,248 +1289,6 @@ brasero_metadata_success_main (BraseroMetadata *self)
 	return brasero_metadata_get_duration (self, priv->pipeline, TRUE);
 }
 
-static void
-brasero_metadata_install_plugins_add_downloaded (GSList *downloads)
-{
-	GSList *iter;
-
-	for (iter = downloads; iter; iter = iter->next) {
-		BraseroMetadataGstDownload *download;
-
-		download = iter->data;
-		downloaded = g_slist_prepend (downloaded, download->detail);
-		download->detail = NULL;
-	}
-}
-
-static void
-brasero_metadata_install_plugins_free_data (GSList *downloads)
-{
-	GSList *iter;
-
-	for (iter = downloads; iter; iter = iter->next) {
-		BraseroMetadataGstDownload *download;
-		GSList *meta;
-
-		download = iter->data;
-		if (download->detail)
-			g_free (download->detail);
-
-		for (meta = download->objects; meta; meta = meta->next) {
-			BraseroMetadataPrivate *priv;
-
-			priv = BRASERO_METADATA_PRIVATE (meta->data);
-			priv->downloads = g_slist_remove (priv->downloads, download);
-		}
-
-		downloading = g_slist_remove (downloading, download);
-
-		g_slist_free (download->objects);
-
-		g_free (download);
-	}
-
-	g_slist_free (downloads);
-}
-
-static void
-brasero_metadata_install_plugins_success (BraseroMetadataGstDownload *download)
-{
-	GSList *iter;
-
-	for (iter = download->objects; iter; iter = iter->next) {
-		BraseroMetadataPrivate *priv;
-
-		priv = BRASERO_METADATA_PRIVATE (iter->data);
-
-		/* free previously saved error message */
-		g_error_free (priv->error);
-		priv->error = NULL;
-
-		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_NULL);
-		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_PLAYING);
-	}
-}
-
-static void
-brasero_metadata_install_plugins_abort (BraseroMetadataGstDownload *download)
-{
-	GSList *iter;
-
-	for (iter = download->objects; iter; iter = iter->next) {
-		BraseroMetadataPrivate *priv;
-
-		priv = BRASERO_METADATA_PRIVATE (iter->data);
-
-		g_error_free (priv->error);
-		priv->error = NULL;
-		brasero_metadata_completed (BRASERO_METADATA (iter->data));
-	}
-}
-
-static void
-brasero_metadata_install_plugins_completed (BraseroMetadataGstDownload *download)
-{
-	GSList *iter;
-	GSList *next;
-
-	for (iter = download->objects; iter; iter = next) {
-		next = iter->next;
-		brasero_metadata_completed (BRASERO_METADATA (iter->data));
-	}
-}
-
-static void
-brasero_metadata_install_plugins_result (GstInstallPluginsReturn res,
-					 gpointer data)
-{
-	GSList *downloads = data;
-	GSList *iter;
-
-	switch (res) {
-	case GST_INSTALL_PLUGINS_PARTIAL_SUCCESS:
-	case GST_INSTALL_PLUGINS_SUCCESS:
-		brasero_metadata_install_plugins_add_downloaded (downloads);
-
-		/* force gst to update plugin list */
-		gst_update_registry ();
-
-		/* restart metadata search */
-		for (iter = downloads; iter; iter = iter->next) {
-			BraseroMetadataGstDownload *download;
-
-			download = iter->data;
-			brasero_metadata_install_plugins_success (download);
-		}
-		break;
-
-	case GST_INSTALL_PLUGINS_NOT_FOUND:
-		brasero_metadata_install_plugins_add_downloaded (downloads);
-
-		/* stop everything */
-		for (iter = downloads; iter; iter = iter->next)
-			brasero_metadata_install_plugins_completed (iter->data);
-		break;
-
-	case GST_INSTALL_PLUGINS_USER_ABORT:
-		brasero_metadata_install_plugins_add_downloaded (downloads);
-
-		/* free previously saved error message */
-		for (iter = downloads; iter; iter = iter->next) {
-			BraseroMetadataGstDownload *download;
-
-			download = iter->data;
-			brasero_metadata_install_plugins_abort (download);
-		}
-		break;
-
-	case GST_INSTALL_PLUGINS_ERROR:
-	case GST_INSTALL_PLUGINS_CRASHED:
-	default:
-		for (iter = downloads; iter; iter = iter->next)
-			brasero_metadata_install_plugins_completed (iter->data);
-
-		break;
-	}
-
-	brasero_metadata_install_plugins_free_data (downloads);
-}
-
-BraseroMetadataGstDownload *
-brasero_metadata_is_downloading (const gchar *detail)
-{
-	GSList *iter;
-
-	for (iter = downloading; iter; iter = iter->next) {
-		BraseroMetadataGstDownload *download;
-
-		download = iter->data;
-		if (!strcmp (download->detail, detail))
-			return download;
-	}
-	return NULL;
-}
-
-static gboolean
-brasero_metadata_install_missing_plugins (BraseroMetadata *self)
-{
-	GstInstallPluginsContext *context;
-	GstInstallPluginsReturn status;
-	BraseroMetadataPrivate *priv;
-	GSList *downloads = NULL;
-	GPtrArray *details;
-	GSList *iter;
-
-	priv = BRASERO_METADATA_PRIVATE (self);
-
-	BRASERO_UTILS_LOG ("Starting to download missing plugins");
-
-	details = g_ptr_array_new ();
-	for (iter = priv->missing_plugins; iter; iter = iter->next) {
-		gchar *detail;
-		BraseroMetadataGstDownload *download;
-
-		/* Check if this plugin:
-		 * - has already been downloaded (whether it was successful or not)
-		 * - is being downloaded
-		 * If so don't do anything.
-		 */
-		detail = gst_missing_plugin_message_get_installer_detail (iter->data);
-		download = brasero_metadata_is_downloading (detail);
-		if (download) {
-			download->objects = g_slist_prepend (download->objects, self);
-			g_free (detail);
-			continue;
-		}
-
-		if (g_slist_find_custom (downloaded, detail, (GCompareFunc) strcmp)) {
-			g_free (detail);
-			continue;
-		}
-
-		download = g_new0 (BraseroMetadataGstDownload, 1);
-		download->detail = detail;
-		download->objects = g_slist_prepend (download->objects, self);
-		priv->downloads = g_slist_prepend (priv->downloads, download);
-
-		downloads = g_slist_prepend (downloads, download);
-		downloading = g_slist_prepend (downloading, download);
-
-		g_ptr_array_add (details, detail);
-	}
-
-	if (!details->len) {
-		/* either these plugins were downloaded or are being downloaded */
-		g_ptr_array_free (details, TRUE);
-		if (!priv->downloads)
-			return FALSE;
-
-		return TRUE;
-	}
-
-	g_ptr_array_add (details, NULL);
-
-	/* FIXME: we'd need the main window here to set it modal */
-
-	context = gst_install_plugins_context_new ();
-	status = gst_install_plugins_async ((gchar **) details->pdata,
-					    context,
-					    brasero_metadata_install_plugins_result,
-					    downloads);
-
-	gst_install_plugins_context_free (context);
-	g_ptr_array_free (details, FALSE);
-
-	BRASERO_UTILS_LOG ("Download status %i", status);
-
-	if (status != GST_INSTALL_PLUGINS_STARTED_OK) {
-		brasero_metadata_install_plugins_free_data (downloads);
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
 static gboolean
 brasero_metadata_bus_messages (GstBus *bus,
 			       GstMessage *msg,
@@ -1096,93 +1305,17 @@ brasero_metadata_bus_messages (GstBus *bus,
 
 	switch (GST_MESSAGE_TYPE (msg)) {
 	case GST_MESSAGE_ELEMENT:
-		/* This is for snapshot function */
-		if (!strcmp (gst_structure_get_name (msg->structure), "preroll-pixbuf")
-		||  !strcmp (gst_structure_get_name (msg->structure), "pixbuf")) {
-			const GValue *value;
-
-			value = gst_structure_get_value (msg->structure, "pixbuf");
-			priv->info->snapshot = g_value_get_object (value);
-			g_object_ref (priv->info->snapshot);
-
-			BRASERO_UTILS_LOG ("Received pixbuf snapshot sink (%p) for %s", priv->info->snapshot, priv->info->uri);
-
-			/* Now we can stop */
-			return brasero_metadata_completed (self);
-		}
-
-		/* here we just want to check if that's a missing codec */
-		if ((priv->flags & BRASERO_METADATA_FLAG_MISSING)
-		     &&   gst_is_missing_plugin_message (msg))
-			priv->missing_plugins = g_slist_prepend (priv->missing_plugins, gst_message_ref (msg));
-		else if (!strcmp (gst_structure_get_name (msg->structure), "level")
-		     &&   gst_structure_has_field (msg->structure, "peak")) {
-			const GValue *value;
-			const GValue *list;
-			gdouble peak;
-
-			list = gst_structure_get_value (msg->structure, "peak");
-			value = gst_value_list_get_value (list, 0);
-			peak = g_value_get_double (value);
-
-			/* detection of silence */
-			if (peak < -50.0) {
-				gint64 pos = -1;
-				GstFormat format = GST_FORMAT_TIME;
-	
-				/* was there a silence last time we check ?
-				 * NOTE: if that's the first signal we receive
-				 * then consider that silence started from 0 */
-				gst_element_query_position (priv->pipeline, &format, &pos);
-				if (pos == -1) {
-					BRASERO_UTILS_LOG ("impossible to retrieve position");
-					return TRUE;
-				}
-
-				if (!priv->silence) {
-					priv->silence = g_new0 (BraseroMetadataSilence, 1);
-					if (priv->prev_level_mes) {
-						priv->silence->start = pos;
-						priv->silence->end = pos;
-					}
-					else {
-						priv->silence->start = 0;
-						priv->silence->end = pos;
-					}
-				}				
-				else
-					priv->silence->end = pos;
-
-				BRASERO_UTILS_LOG ("silence detected at %lli", pos);
-			}
-			else if (priv->silence) {
-				BRASERO_UTILS_LOG ("silence finished");
-
-				priv->info->silences = g_slist_append (priv->info->silences,
-								       priv->silence);
-				priv->silence = NULL;
-			}
-			priv->prev_level_mes = 1;
-		}
-		break;
+		return brasero_metadata_process_element_messages (self, msg);
 
 	case GST_MESSAGE_ERROR:
 		/* save the error message */
 		gst_message_parse_error (msg, &error, &debug_string);
-		BRASERO_UTILS_LOG ("Gstreamer error (%s)", debug_string);
+		BRASERO_UTILS_LOG ("GStreamer error (%s)", debug_string);
 		g_free (debug_string);
 		if (!priv->error && error)
 			priv->error = error;
 
-		/* See if we have missing plugins */
-		if (priv->missing_plugins) {
-			if (!brasero_metadata_install_missing_plugins (self))
-				return brasero_metadata_completed (self);
-		}
-		else
-			return brasero_metadata_completed (self);
-
-		break;
+		return brasero_metadata_completed (self);
 
 	case GST_MESSAGE_EOS:
 		BRASERO_UTILS_LOG ("End of stream reached for %s", priv->info->uri);
@@ -1237,6 +1370,23 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 		 * around after the bin they've been added to is destroyed
 		 * NOTE: now we destroy the pipeline every time which means
 		 * that it doesn't really matter. */
+		if (!priv->level) {
+			priv->level = gst_element_factory_make ("level", NULL);
+			if (!priv->level) {
+				priv->error = g_error_new (BRASERO_UTILS_ERROR,
+							   BRASERO_UTILS_ERROR_GENERAL,
+							   _("%s element could not be created"),
+							   "\"Level\"");
+				gst_object_unref (priv->audio);
+				priv->audio = NULL;
+				return FALSE;
+			}
+			g_object_set (priv->level,
+				      "message", TRUE,
+				      "interval", (guint64) BRASERO_METADATA_SILENCE_INTERVAL,
+				      NULL);
+		}
+
 		gst_object_ref (priv->convert);
 		gst_object_ref (priv->level);
 		gst_object_ref (priv->sink);
@@ -1246,10 +1396,17 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 				  priv->level,
 				  priv->sink,
 				  NULL);
-		gst_element_link_many (priv->convert,
-				       priv->level,
-				       priv->sink,
-				       NULL);
+
+		if (!gst_element_link_many (priv->convert,
+		                            priv->level,
+		                            priv->sink,
+		                            NULL)) {
+			BRASERO_UTILS_LOG ("Impossible to link elements");
+			gst_object_unref (priv->audio);
+			priv->audio = NULL;
+			return FALSE;
+		}
+
 		audio_pad = gst_element_get_static_pad (priv->convert, "sink");
 	}
 	else if (priv->flags & BRASERO_METADATA_FLAG_THUMBNAIL) {
@@ -1264,10 +1421,16 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 				  priv->convert,
 				  priv->sink,
 				  NULL);
-		gst_element_link_many (queue,
-				       priv->convert,
-				       priv->sink,
-				       NULL);
+		if (!gst_element_link_many (queue,
+		                            priv->convert,
+		                            priv->sink,
+		                            NULL)) {
+			BRASERO_UTILS_LOG ("Impossible to link elements");
+			gst_object_unref (priv->audio);
+			priv->audio = NULL;
+			return FALSE;
+		}
+
 		audio_pad = gst_element_get_static_pad (queue, "sink");
 	}
 	else {
@@ -1279,7 +1442,13 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 		gst_object_ref (priv->sink);
 		gst_bin_add (GST_BIN (priv->audio), priv->sink);
 
-		gst_element_link (queue, priv->sink);
+		if (!gst_element_link (queue, priv->sink)) {
+			BRASERO_UTILS_LOG ("Impossible to link elements");
+			gst_object_unref (priv->audio);
+			priv->audio = NULL;
+			return FALSE;
+		}
+
 		audio_pad = gst_element_get_static_pad (queue, "sink");
 	}
 
@@ -1333,10 +1502,16 @@ brasero_metadata_create_video_pipeline (BraseroMetadata *self)
 	gst_bin_add (GST_BIN (priv->video), queue);
 
 	/* link elements */
-	gst_element_link_many (queue,
-			       colorspace,
-			       priv->snapshot,
-			       NULL);
+	if (!gst_element_link_many (queue,
+	                            colorspace,
+	                            priv->snapshot,
+	                            NULL)) {
+		gst_object_unref (priv->video);
+		priv->video = NULL;
+
+		BRASERO_UTILS_LOG ("Impossible to link elements");
+		return FALSE;
+	}
 
 	video_pad = gst_element_get_static_pad (queue, "sink");
 	gst_element_add_pad (priv->video, gst_ghost_pad_new ("sink", video_pad));
@@ -1403,6 +1578,70 @@ brasero_metadata_link_dummy_pad (BraseroMetadata *self,
 	return FALSE;
 }
 
+static void
+brasero_metadata_audio_caps (BraseroMetadata *self,
+                             GstCaps *caps)
+{
+	int i;
+	int num_caps;
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (self);
+
+	num_caps = gst_caps_get_size (caps);
+	for (i = 0; i < num_caps; i++) {
+		const GstStructure *structure;
+
+		structure = gst_caps_get_structure (caps, i);
+		if (!structure)
+			continue;
+
+		if (gst_structure_has_field (structure, "channels")) {
+			if (gst_structure_get_field_type (structure, "channels") == G_TYPE_INT) {
+				priv->info->channels = 0;
+				gst_structure_get_int (structure, "channels", &priv->info->channels);
+
+				BRASERO_UTILS_LOG ("Number of channels %i", priv->info->channels);
+			}
+			else if (gst_structure_get_field_type (structure, "channels") == GST_TYPE_INT_RANGE) {
+				const GValue *value;
+
+				value = gst_structure_get_value (structure, "channels");
+				if (value) {
+					priv->info->channels = gst_value_get_int_range_max (value);
+					BRASERO_UTILS_LOG ("Number of channels %i", priv->info->channels);
+				}
+			}
+			else if (gst_structure_get_field_type (structure, "channels") != G_TYPE_INVALID) {
+				BRASERO_UTILS_LOG ("Unhandled type for channel prop %s",
+				                   g_type_name (gst_structure_get_field_type (structure, "channels")));
+			}
+		}
+
+		if (gst_structure_has_field (structure, "rate")) {
+			if (gst_structure_get_field_type (structure, "rate") == G_TYPE_INT) {
+				priv->info->rate = 0;
+				gst_structure_get_int (structure, "rate", &priv->info->rate);
+
+				BRASERO_UTILS_LOG ("Rate %i", priv->info->rate);
+			}
+			else if (gst_structure_get_field_type (structure, "rate") == GST_TYPE_INT_RANGE) {
+				const GValue *value;
+
+				value = gst_structure_get_value (structure, "rate");
+				if (value) {
+					priv->info->rate = gst_value_get_int_range_max (value);
+					BRASERO_UTILS_LOG ("Rate %i", priv->info->rate);
+				}
+			}
+			else if (gst_structure_get_field_type (structure, "rate") != G_TYPE_INVALID) {
+				BRASERO_UTILS_LOG ("Unhandled type for rate prop %s",
+				                   g_type_name (gst_structure_get_field_type (structure, "rate")));
+			}
+		}
+	}
+}
+
 static void
 brasero_metadata_new_decoded_pad_cb (GstElement *decode,
 				     GstPad *pad,
@@ -1431,12 +1670,14 @@ brasero_metadata_new_decoded_pad_cb (GstElement *decode,
 		return;
 
 	name = gst_structure_get_name (structure);
+
 	has_audio = (g_strrstr (name, "audio") != NULL);
 	has_video = (g_strrstr (name, "video") != NULL);
 	priv->info->has_audio |= has_audio;
 	priv->info->has_video |= has_video;
 
 	if (has_audio && !priv->audio_linked) {
+		brasero_metadata_audio_caps (self, caps);
 		brasero_metadata_create_audio_pipeline (self);
 		sink = gst_element_get_static_pad (priv->audio, "sink");
 		if (sink && !GST_PAD_IS_LINKED (sink)) {
@@ -1525,19 +1766,6 @@ brasero_metadata_create_pipeline (BraseroMetadata *self)
 		return FALSE;
 	}
 
-	priv->level = gst_element_factory_make ("level", NULL);
-	if (!priv->level) {
-		priv->error = g_error_new (BRASERO_UTILS_ERROR,
-					   BRASERO_UTILS_ERROR_GENERAL,
-					   _("%s element could not be created"),
-					   "\"Level\"");
-		return FALSE;
-	}
-	g_object_set (priv->level,
-		      "message", TRUE,
-		      "interval", (guint64) BRASERO_METADATA_SILENCE_INTERVAL,
-		      NULL);
-
 	priv->sink = gst_element_factory_make ("fakesink", NULL);
 	if (priv->sink == NULL) {
 		priv->error = g_error_new (BRASERO_UTILS_ERROR,
@@ -1647,8 +1875,11 @@ brasero_metadata_set_uri (BraseroMetadata *self,
 
 	priv->flags = flags;
 	if (!brasero_metadata_set_new_uri (self, uri)) {
-		g_propagate_error (error, priv->error);
-		priv->error = NULL;
+		if (priv->error) {
+			BRASERO_UTILS_LOG ("Failed to set new URI %s", priv->error->message);
+			g_propagate_error (error, priv->error);
+			priv->error = NULL;
+		}
 
 		brasero_metadata_info_free (priv->info);
 		priv->info = NULL;
@@ -1690,6 +1921,7 @@ brasero_metadata_get_info_async (BraseroMetadata *self,
 		g_object_unref (self);
 
 		if (priv->error) {
+			BRASERO_UTILS_LOG ("Failed to set new URI %s", priv->error->message);
 			g_error_free (priv->error);
 			priv->error = NULL;
 		}
@@ -1870,7 +2102,7 @@ brasero_metadata_finalize (GObject *object)
 		priv->mutex = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (brasero_metadata_parent_class)->finalize (object);
 }
 
 static void
@@ -1934,8 +2166,6 @@ brasero_metadata_class_init (BraseroMetadataClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	g_type_class_add_private (klass, sizeof (BraseroMetadataPrivate));
 
 	object_class->finalize = brasero_metadata_finalize;
