@@ -37,6 +37,7 @@
 #include "brasero-medium.h"
 #include "brasero-volume.h"
 
+#include "brasero-tags.h"
 #include "brasero-session.h"
 #include "brasero-track-data-cfg.h"
 
@@ -88,18 +89,9 @@ static void
 brasero_project_name_icon_update (BraseroProjectName *self,
 				  BraseroTrackDataCfg *track)
 {
-	GError *error = NULL;
-	GdkPixbuf *pixbuf;
-	const gchar *icon; 
+	GIcon *icon; 
 
-	gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (self),
-					GTK_ENTRY_ICON_PRIMARY,
-					NULL);	
-	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (self),
-					   GTK_ENTRY_ICON_PRIMARY,
-					   NULL);
-
-	icon = brasero_track_data_cfg_get_icon_path (track);
+	icon = brasero_track_data_cfg_get_icon (track);
 	if (!icon) {
 		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (self),
 						   GTK_ENTRY_ICON_PRIMARY,
@@ -107,25 +99,11 @@ brasero_project_name_icon_update (BraseroProjectName *self,
 		return;
 	}
 
-	/* Load and convert the image into a pixbuf */
-	pixbuf = gdk_pixbuf_new_from_file_at_scale (icon,
-						    24,
-						    24,
-						    FALSE,
-						    &error);
-	if (!pixbuf) {
-		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (self),
-						   GTK_ENTRY_ICON_PRIMARY,
-						   "media-optical");
-		brasero_project_name_data_icon_error (self, error);
-		g_error_free (error);
-		return;
-	}
+	gtk_entry_set_icon_from_gicon (GTK_ENTRY (self),
+	                               GTK_ENTRY_ICON_PRIMARY,
+	                               icon);
 
-	gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (self),
-					GTK_ENTRY_ICON_PRIMARY,
-					pixbuf);
-	g_object_unref (pixbuf);
+	g_object_unref (icon);
 }
 
 static void
@@ -164,7 +142,7 @@ brasero_project_name_icon_button_clicked (BraseroProjectName *project,
 	BraseroProjectNamePrivate *priv;
 	BraseroTrackDataCfg *track;
 	GtkFileFilter *filter;
-	const gchar *filename;
+	gchar *filename;
 	GError *error = NULL;
 	GtkWidget *chooser;
 	gchar *path;
@@ -176,8 +154,6 @@ brasero_project_name_icon_button_clicked (BraseroProjectName *project,
 	if (!track)
 		return;
 
-	filename = brasero_track_data_cfg_get_icon_path (track);
-
 	chooser = gtk_file_chooser_dialog_new (_("Medium Icon"),
 					       GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (project))),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -198,8 +174,11 @@ brasero_project_name_icon_button_clicked (BraseroProjectName *project,
 
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (chooser), filter);
 
-	if (filename)
+	filename = brasero_track_data_cfg_get_icon_path (track);
+	if (filename) {
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (chooser), filename);
+		g_free (filename);
+	}
 
 	gtk_widget_show (chooser);
 	res = gtk_dialog_run (GTK_DIALOG (chooser));
@@ -291,11 +270,63 @@ brasero_project_name_get_default_label (BraseroProjectName *self)
 			 * 32 _bytes_.
 			 * The %s is the date */
 			title_str = g_strdup_printf (_("Video disc (%s)"), buffer);
-		else if (priv->type == BRASERO_PROJECT_TYPE_AUDIO)
-			/* NOTE to translators: the final string must not be over
-			 * 32 _bytes_ .
-			 * The %s is the date */
-			title_str = g_strdup_printf (_("Audio disc (%s)"), buffer);
+		else if (priv->type == BRASERO_PROJECT_TYPE_AUDIO) {
+			GSList *tracks;
+			const gchar *album = NULL;
+			const gchar *artist = NULL;
+			gboolean default_album_name = TRUE;
+
+			/* Go through all audio tracks and see if they have the 
+			 * same album and artist name. If so set the album name */
+			tracks = brasero_burn_session_get_tracks (priv->session);
+			for (; tracks; tracks = tracks->next) {
+				BraseroTrack *track;
+				const gchar *tmp_album;
+				const gchar *tmp_artist;
+
+				track = tracks->data;
+
+				tmp_album = brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_ALBUM_TAG);
+
+				if (!tmp_album) {
+					default_album_name = FALSE;
+					break;
+				}
+
+				if (album) {
+					if (strcmp (tmp_album, album)) {
+						default_album_name = FALSE;
+						break;
+					}
+				}
+				else
+					album = tmp_album;
+
+				tmp_artist = brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_ARTIST_TAG);
+				if (!tmp_artist) {
+					default_album_name = FALSE;
+					break;
+				}
+
+				if (artist) {
+					if (strcmp (tmp_artist, artist)) {
+						default_album_name = FALSE;
+						break;
+					}
+				}
+				else
+					artist = tmp_artist;
+			}
+
+			if (!artist || !album || !default_album_name) {
+				/* NOTE to translators: the final string must not be over
+				 * 32 _bytes_ .
+				 * The %s is the date */
+				title_str = g_strdup_printf (_("Audio disc (%s)"), buffer);
+			}
+			else
+				title_str = g_strdup (album);
+		}
 
 		if (strlen (title_str) > 32) {
 			g_free (title_str);
@@ -411,9 +442,18 @@ brasero_project_name_set_type (BraseroProjectName *self)
 	BraseroTrackType *track_type;
 	BraseroProjectType type;
 	gchar *title_str = NULL;
+	BraseroStatus *status;
 
 	priv = BRASERO_PROJECT_NAME_PRIVATE (self);
 
+	status = brasero_status_new ();
+	brasero_burn_session_get_status (priv->session, status);
+	if (brasero_status_get_result (status) != BRASERO_BURN_OK) {
+		g_object_unref (status);
+		return;
+	}
+	g_object_unref (status);
+
 	track_type = brasero_track_type_new ();
 	brasero_burn_session_get_input_type (priv->session, track_type);
 
@@ -430,8 +470,12 @@ brasero_project_name_set_type (BraseroProjectName *self)
 
 	brasero_track_type_free (track_type);
 
-	if (priv->type == type)
-		return;
+	/* This is not necessarily true for audio projects as those can have the
+	 * name of their album set as default; so it could easily change */
+	if (type != BRASERO_PROJECT_TYPE_AUDIO) {
+		if (priv->type == type)
+			return;
+	}
 
 	priv->type = type;
 	priv->label_modified = FALSE;
@@ -509,22 +553,12 @@ brasero_project_name_session_changed (BraseroProjectName *self)
 					  G_CALLBACK (brasero_project_name_icon_changed_cb),
 					  self);
 			brasero_project_name_icon_update (self, track);
-			gtk_entry_set_icon_tooltip_text (GTK_ENTRY (self),
-							 GTK_ENTRY_ICON_PRIMARY,
-							 _("Select an icon for the disc that will appear in file managers"));
 		}
 	}
-	else {
-		gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (self),
-						GTK_ENTRY_ICON_PRIMARY,
-						NULL);
-		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (self),
-						   GTK_ENTRY_ICON_PRIMARY,
-						   NULL);
-		gtk_entry_set_icon_tooltip_text (GTK_ENTRY (self),
-						 GTK_ENTRY_ICON_PRIMARY,
-						 NULL);
-	}
+	else
+		gtk_entry_set_icon_from_gicon (GTK_ENTRY (self),
+		                               GTK_ENTRY_ICON_PRIMARY,
+		                               NULL);
 
 	brasero_track_type_free (type);
 
@@ -603,6 +637,7 @@ brasero_project_name_set_session (BraseroProjectName *project,
 		return;
 
 	priv->session = g_object_ref (session);
+
 	g_signal_connect (priv->session,
 			  "track-added",
 			  G_CALLBACK (brasero_project_name_track_added),
