@@ -59,6 +59,8 @@
 #endif
 
 #include "brasero-track-data.h"
+#include "brasero-track-data-cfg.h"
+#include "brasero-track-stream-cfg.h"
 #include "brasero-session-cfg.h"
 
 /* These includes are not in the exported *.h files by 
@@ -1292,7 +1294,7 @@ brasero_project_check_status (BraseroProject *project)
 		return BRASERO_BURN_OK;
 
         dialog = brasero_status_dialog_new (BRASERO_BURN_SESSION (project->priv->session),
-                                                                  gtk_widget_get_toplevel (GTK_WIDGET (project)));
+                                            gtk_widget_get_toplevel (GTK_WIDGET (project)));
 
 	gtk_widget_show (dialog);
         response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1376,8 +1378,8 @@ brasero_project_list_missing (BraseroPluginErrorType type,
 	}
 	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
 		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing Gstreamer plugin */
-		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
+		/* Translators: %s is the name of a missing GStreamer plugin */
+		g_string_append_printf (string, _("%s (GStreamer plugin)"), detail);
 	}
 
 	return BRASERO_BURN_OK;
@@ -1394,14 +1396,29 @@ brasero_project_check_plugins_not_ready (BraseroProject *project,
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
 	gtk_widget_set_sensitive (parent, FALSE);
 
+	brasero_burn_session_set_strict_support (BRASERO_BURN_SESSION (session), TRUE);
+	result = brasero_burn_session_can_burn (session, FALSE);
+	brasero_burn_session_set_strict_support (BRASERO_BURN_SESSION (session), FALSE);
+
+	if (result == BRASERO_BURN_OK) {
+		gtk_widget_set_sensitive (parent, TRUE);
+		return result;
+	}
+
+	result = brasero_burn_session_can_burn (session, FALSE);
+	if (result != BRASERO_BURN_OK) {
+		gtk_widget_set_sensitive (parent, TRUE);
+		return result;
+	}
+
 	result = brasero_session_foreach_plugin_error (session,
 	                                               brasero_project_install_missing,
 	                                               project);
+	gtk_widget_set_sensitive (parent, TRUE);
+
 	if (result == BRASERO_BURN_CANCEL)
 		return result;
 
-	gtk_widget_set_sensitive (parent, TRUE);
-
 	if (result == BRASERO_BURN_OK)
 		return result;
 
@@ -1441,7 +1458,7 @@ brasero_project_setup_session (BraseroProject *project,
 	}
 }
 
-static gboolean
+static BraseroBurnResult
 brasero_project_drive_properties (BraseroProject *project)
 {
 	BraseroTrackType *track_type;
@@ -1472,6 +1489,10 @@ brasero_project_drive_properties (BraseroProject *project)
 					      NULL);
 	g_free (header);
 
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("Burn _Several Copies"),
+			       GTK_RESPONSE_ACCEPT);
+
 	button = brasero_utils_make_button (_("_Burn"),
 					    NULL,
 					    "media-optical-burn",
@@ -1512,7 +1533,13 @@ brasero_project_drive_properties (BraseroProject *project)
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer == GTK_RESPONSE_OK);
+	if (answer == GTK_RESPONSE_OK)
+		return BRASERO_BURN_OK;
+
+	if (answer == GTK_RESPONSE_ACCEPT)
+		return BRASERO_BURN_RETRY;
+
+	return BRASERO_BURN_CANCEL;
 }
 
 static gboolean
@@ -1530,18 +1557,14 @@ brasero_project_image_properties (BraseroProject *project)
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       GTK_STOCK_CANCEL,
+			       GTK_RESPONSE_CANCEL);
 
-	button = brasero_utils_make_button (_("_Burn"),
-					    NULL,
-					    "media-optical-burn",
-					    GTK_ICON_SIZE_BUTTON);
-	gtk_widget_show (button);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-				      button,
-				      GTK_RESPONSE_OK);
-
-	gtk_widget_set_can_default (button, TRUE);
+	button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+					_("Create _Image"),
+				       GTK_RESPONSE_OK);
+	gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name ("iso-image-new", GTK_ICON_SIZE_BUTTON));
 
 	brasero_image_properties_set_session (BRASERO_IMAGE_PROPERTIES (dialog), project->priv->session);
 
@@ -1569,13 +1592,13 @@ brasero_project_image_properties (BraseroProject *project)
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer == GTK_RESPONSE_OK);
+	return (answer == GTK_RESPONSE_OK) ? BRASERO_BURN_OK:BRASERO_BURN_ERR;
 }
 
 void
 brasero_project_burn (BraseroProject *project)
 {
-	gboolean res = FALSE;
+	BraseroBurnResult res;
 	BraseroDisc *current_disc;
 
 	/* Check that we are ready */
@@ -1591,7 +1614,7 @@ brasero_project_burn (BraseroProject *project)
 	else
 		res = brasero_project_image_properties (project);
 
-	if (!res)
+	if (res != BRASERO_BURN_OK && res != BRASERO_BURN_RETRY)
 		return;
 
 	project->priv->is_burning = 1;
@@ -1609,8 +1632,9 @@ brasero_project_burn (BraseroProject *project)
 	brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (project));
 
 	/* now setup the burn dialog */
-	if (brasero_app_burn (brasero_app_get_default (), BRASERO_BURN_SESSION (project->priv->session)))
-		project->priv->burnt = TRUE;
+	project->priv->burnt = brasero_app_burn (brasero_app_get_default (),
+						 BRASERO_BURN_SESSION (project->priv->session),
+						 res == BRASERO_BURN_RETRY);
 
 	/* empty the stack of temporary tracks */
 	while (brasero_burn_session_pop_tracks (BRASERO_BURN_SESSION (project->priv->session)) == BRASERO_BURN_RETRY);
@@ -1636,7 +1660,13 @@ brasero_project_create_audio_cover (BraseroProject *project)
 	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
 	window = brasero_session_edit_cover (BRASERO_BURN_SESSION (project->priv->session),
 					     gtk_widget_get_toplevel (GTK_WIDGET (project)));
-	gtk_dialog_run (GTK_DIALOG (window));
+
+	/* This strange hack is a way to workaround #568358.
+	 * At one point we'll need to hide the dialog which means it
+	 * will anwer with a GTK_RESPONSE_NONE */
+	while (gtk_dialog_run (GTK_DIALOG (window)) == GTK_RESPONSE_NONE)
+		gtk_widget_show (GTK_WIDGET (window));
+
 	gtk_widget_destroy (window);
 }
 
@@ -1819,8 +1849,9 @@ brasero_project_set_video (BraseroProject *project)
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_VIDEO);
 }
 
-gboolean
-brasero_project_confirm_switch (BraseroProject *project)
+BraseroBurnResult
+brasero_project_confirm_switch (BraseroProject *project,
+				gboolean keep_files)
 {
 	GtkWidget *dialog;
 	GtkResponseType answer;
@@ -1835,10 +1866,30 @@ brasero_project_confirm_switch (BraseroProject *project)
 					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("If you choose to create a new project, all changes made will be lost."));
-		gtk_dialog_add_button (GTK_DIALOG (dialog),
-				       _("_Discard Changes"), GTK_RESPONSE_OK);
+							  _("If you choose to create a new empty project, all changes will be lost."));
 
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Discard Changes"),
+				       GTK_RESPONSE_OK);
+	}
+	else if (keep_files) {
+		if (project->priv->empty)
+			return TRUE;
+
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					     _("Do you want to discard the file selection or add it to the new project?"),
+					     GTK_BUTTONS_CANCEL,
+					     GTK_MESSAGE_WARNING);
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("If you choose to create a new empty project, the file selection will be discarded."));
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Discard File Selection"),
+				       GTK_RESPONSE_OK);
+
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Keep File Selection"),
+				       GTK_RESPONSE_ACCEPT);
 	}
 	else {
 		if (project->priv->empty)
@@ -1850,21 +1901,22 @@ brasero_project_confirm_switch (BraseroProject *project)
 					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("If you choose to create a new project, "
-							    "all files already added will be discarded. "
-							    "Note that files will not be deleted from their own location, "
-							    "just no longer listed here."));
+							  _("If you choose to create a new empty project, the file selection will be discarded."));
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
-				       _("_Discard Project"), GTK_RESPONSE_OK);
+				       _("_Discard Project"),
+				       GTK_RESPONSE_OK);
 	}
 
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	if (answer != GTK_RESPONSE_OK)
-		return FALSE;
+	if (answer == GTK_RESPONSE_ACCEPT)
+		return BRASERO_BURN_RETRY;
 
-	return TRUE;
+	if (answer != GTK_RESPONSE_OK)
+		return BRASERO_BURN_CANCEL;
+
+	return BRASERO_BURN_OK;
 }
 
 void
@@ -2286,7 +2338,7 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 
 	project->priv->manager = manager;
 
-	if (GTK_WIDGET_REALIZED (project->priv->name_display))
+	if (gtk_widget_get_realized (project->priv->name_display))
 		gtk_widget_grab_focus (project->priv->name_display);
 }
 
@@ -2433,6 +2485,84 @@ brasero_project_open_session (BraseroProject *project,
 	return type;
 }
 
+BraseroProjectType
+brasero_project_convert_to_data (BraseroProject *project)
+{
+	GSList *tracks;
+	BraseroProjectType type;
+	BraseroSessionCfg *newsession;
+	BraseroTrackDataCfg *data_track;
+
+	newsession = brasero_session_cfg_new ();
+	data_track = brasero_track_data_cfg_new ();
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (newsession),
+					BRASERO_TRACK (data_track),
+					NULL);
+	g_object_unref (data_track);
+
+	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (project->priv->session));
+	for (; tracks; tracks = tracks->next) {
+		BraseroTrackStream *track;
+		gchar *uri;
+
+		track = tracks->data;
+		uri = brasero_track_stream_get_source (track, TRUE);
+		brasero_track_data_cfg_add (data_track, uri, NULL);
+		g_free (uri);
+	}
+
+	type = brasero_project_open_session (project, newsession);
+	g_object_unref (newsession);
+
+	return type;
+}
+
+BraseroProjectType
+brasero_project_convert_to_stream (BraseroProject *project,
+				   gboolean is_video)
+{
+	GSList *tracks;
+	GtkTreeIter iter;
+	BraseroProjectType type;
+	BraseroSessionCfg *newsession;
+	BraseroTrackDataCfg *data_track;
+
+	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (project->priv->session));
+	if (!tracks)
+		return BRASERO_PROJECT_TYPE_INVALID;
+
+	data_track = tracks->data;
+	if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (data_track), &iter))
+		return BRASERO_PROJECT_TYPE_INVALID;
+
+	newsession = brasero_session_cfg_new ();
+	do {
+		gchar *uri;
+		BraseroTrackStreamCfg *track;
+
+		gtk_tree_model_get (GTK_TREE_MODEL (data_track), &iter,
+				    BRASERO_DATA_TREE_MODEL_URI, &uri,
+				    -1);
+
+		track = brasero_track_stream_cfg_new ();
+		brasero_track_stream_set_source (BRASERO_TRACK_STREAM (track), uri);
+		brasero_track_stream_set_format (BRASERO_TRACK_STREAM (track),
+						 is_video ? BRASERO_VIDEO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_UNDEFINED);
+		g_free (uri);
+
+		brasero_burn_session_add_track (BRASERO_BURN_SESSION (newsession),
+						BRASERO_TRACK (track),
+						NULL);
+		g_object_unref (track);
+
+	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (data_track), &iter));
+
+	type = brasero_project_open_session (project, newsession);
+	g_object_unref (newsession);
+
+	return type;
+}
+
 /******************************** save project *********************************/
 static void
 brasero_project_not_saved_dialog (BraseroProject *project)
