@@ -28,39 +28,17 @@
 #  include <config.h>
 #endif
 
-#ifdef BUILD_SEARCH
-
 #include <string.h>
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 #include <glib-object.h>
 
-#include <gtk/gtktable.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcomboboxentry.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkdialog.h>
-
-#include <beagle/beagle.h>
-
-#include <gconf/gconf-client.h>
+#include <gtk/gtk.h>
 
 #include "brasero-search-entry.h"
 #include "brasero-layout.h"
+#include "brasero-setting.h"
 
 static void brasero_search_entry_class_init (BraseroSearchEntryClass *klass);
 static void brasero_search_entry_init (BraseroSearchEntry *sp);
@@ -70,9 +48,6 @@ static void brasero_search_entry_destroy (GtkObject *gtk_object);
 struct BraseroSearchEntryPrivate {
 	GtkWidget *button;
 	GtkWidget *combo;
-	GSList *history;
-	GConfClient *client;
-	guint cxn;
 	gint search_id;
 
 	BraseroLayoutType ctx;
@@ -94,20 +69,15 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
-#define BRASERO_CONF_DIR "/apps/brasero"
-#define BRASERO_SEARCH_ENTRY_HISTORY_KEY "/apps/brasero/search_history"
 #define BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS	10
 
-static void brasero_search_entry_history_changed_cb (GConfClient *client,
-						      guint cxn_id,
-						      GConfEntry *entry,
-						      BraseroSearchEntry *widget);
 static void brasero_search_entry_button_clicked_cb (GtkButton *button,
 						      BraseroSearchEntry *entry);
 static void brasero_search_entry_entry_activated_cb (GtkComboBox *combo,
 						      BraseroSearchEntry *entry);
 static void brasero_search_entry_activated (BraseroSearchEntry *entry, gboolean query_now);
-static void brasero_search_entry_set_history (BraseroSearchEntry *entry);
+static void brasero_search_entry_set_history (BraseroSearchEntry *entry,
+                                              const gchar * const *history);
 static void brasero_search_entry_save_history (BraseroSearchEntry *entry);
 static void brasero_search_entry_add_current_keyword_to_history (BraseroSearchEntry *entry);
 static void brasero_search_entry_category_clicked_cb (GtkWidget *button, BraseroSearchEntry *entry);
@@ -137,7 +107,7 @@ brasero_search_entry_get_type ()
 			(GInstanceInitFunc) brasero_search_entry_init,
 		};
 
-		type = g_type_register_static (GTK_TYPE_VBOX,
+		type = g_type_register_static (GTK_TYPE_TABLE,
 					       "BraseroSearchEntry",
 					       &our_info,
 					       0);
@@ -190,32 +160,41 @@ static void
 brasero_search_entry_init (BraseroSearchEntry *obj)
 {
 	gchar *string;
-	GtkWidget *box;
+	gpointer value;
 	GtkWidget *table;
 	GtkWidget *label;
 	GtkWidget *entry;
-	GError *error = NULL;
 	GtkListStore *store;
 	GtkCellRenderer *renderer;
 	GtkEntryCompletion *completion;
 
-	gtk_box_set_spacing (GTK_BOX (obj), 6);
+	gtk_table_set_row_spacings (GTK_TABLE (obj), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (obj), 6);
+	gtk_table_resize (GTK_TABLE (obj), 2, 3);
 	obj->priv = g_new0 (BraseroSearchEntryPrivate, 1);
 
-	box = gtk_hbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (obj), box, FALSE, FALSE, 0);
-
-	/* Translators: This string is followed later by "only in\t" */
-	string = g_strdup_printf ("<b>%s</b>", _("Search:\t"));
+	string = g_strdup_printf ("<b>%s</b>", _("Search:"));
 	label = gtk_label_new (string);
 	g_free (string);
 
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+	gtk_table_attach (GTK_TABLE (obj),
+			  label,
+			  0, 1,
+			  0, 1,
+			  GTK_FILL,
+			  GTK_FILL,
+			  2, 2);
 
 	obj->priv->button = gtk_button_new_from_stock (GTK_STOCK_FIND);
-	/* gtk_widget_set_sensitive (obj->priv->button, FALSE); */
-	gtk_box_pack_end (GTK_BOX (box), obj->priv->button, FALSE, FALSE, 0);
+	gtk_table_attach (GTK_TABLE (obj),
+			  obj->priv->button,
+			  2, 3,
+			  0, 1,
+			  GTK_FILL,
+			  GTK_FILL,
+			  0, 0);
+
 	g_signal_connect (G_OBJECT (obj->priv->button),
 			  "clicked",
 			  G_CALLBACK (brasero_search_entry_button_clicked_cb),
@@ -257,36 +236,28 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 	gtk_entry_completion_set_text_column (completion, BRASERO_SEARCH_ENTRY_DISPLAY_COL);
 	gtk_entry_set_completion (GTK_ENTRY (entry), completion);
 
-	gtk_box_pack_start (GTK_BOX (box),
-			    obj->priv->combo,
-			    TRUE,
-			    TRUE,
-			    0);
+	gtk_table_attach (GTK_TABLE (obj),
+			  obj->priv->combo,
+			  1, 2,
+			  0, 1,
+			  GTK_FILL|GTK_EXPAND,
+			  GTK_FILL,
+			  0, 0);
 
-	/* table */
-	table = gtk_table_new (2, 3, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+	/* Table with filtering options */
+	table = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 10);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 
-	gtk_box_pack_end (GTK_BOX (obj), table, FALSE, FALSE, 0);
+	gtk_table_attach (GTK_TABLE (obj),
+			  table,
+			  1, 2,
+			  1, 2,
+			  GTK_FILL,
+			  GTK_FILL,
+			  0, 0);
 
-	/* Translators: This is the end of the previous sentence  "Search:\t" */
-	string = g_strdup_printf ("<b>%s</b>", _("only in\t"));
-	label = gtk_label_new (string);
-	g_free (string);
-
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_table_attach (GTK_TABLE (table),
-			  label,
-			  0, 1,
-			  0, 1,
-			  0,
-			  0,
-			  0,
-			  0);
-
-	obj->priv->documents = gtk_check_button_new_with_mnemonic (_("_text documents"));
+	obj->priv->documents = gtk_check_button_new_with_mnemonic (_("In _text documents"));
 	gtk_button_set_alignment (GTK_BUTTON (obj->priv->documents), 0.0, 0.0);
 	gtk_table_attach (GTK_TABLE (table),
 			  obj->priv->documents,
@@ -301,7 +272,7 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 			  G_CALLBACK (brasero_search_entry_category_clicked_cb),
 			  obj);
 
-	obj->priv->pictures = gtk_check_button_new_with_mnemonic (_("_pictures"));
+	obj->priv->pictures = gtk_check_button_new_with_mnemonic (_("In _pictures"));
 	gtk_button_set_alignment (GTK_BUTTON (obj->priv->pictures), 0.0, 0.0);
 	gtk_table_attach (GTK_TABLE (table),
 			  obj->priv->pictures,
@@ -316,7 +287,7 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 			  G_CALLBACK (brasero_search_entry_category_clicked_cb),
 			  obj);
 
-	obj->priv->music = gtk_check_button_new_with_mnemonic (_("_music"));
+	obj->priv->music = gtk_check_button_new_with_mnemonic (_("In _music"));
 	gtk_button_set_alignment (GTK_BUTTON (obj->priv->music), 0.0, 0.0);
 	gtk_table_attach (GTK_TABLE (table),
 			  obj->priv->music,
@@ -331,7 +302,7 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 			  G_CALLBACK (brasero_search_entry_category_clicked_cb),
 			  obj);
 
-	obj->priv->video = gtk_check_button_new_with_mnemonic (_("_video"));
+	obj->priv->video = gtk_check_button_new_with_mnemonic (_("In _videos"));
 	gtk_button_set_alignment (GTK_BUTTON (obj->priv->video), 0.0, 0.0);
 	gtk_table_attach (GTK_TABLE (table),
 			  obj->priv->video,
@@ -349,6 +320,7 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 	/* add tooltips */
 	gtk_widget_set_tooltip_text (GTK_BIN (obj->priv->combo)->child,
 				     _("Type your keywords or choose 'All files' from the menu"));
+	/* Translators: this is an image, a picture, not a "Disc Image" */
 	gtk_widget_set_tooltip_text (obj->priv->pictures,
 				     _("Select if you want to search among image files only"));
 	gtk_widget_set_tooltip_text (obj->priv->video,
@@ -360,56 +332,17 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 	gtk_widget_set_tooltip_text (obj->priv->button,
 				     _("Click to start the search"));
 
-	/* Set up GConf Client */
-	obj->priv->client = gconf_client_get_default ();
-	if (obj->priv->client) {
-		gconf_client_add_dir (obj->priv->client, BRASERO_CONF_DIR,
-				      GCONF_CLIENT_PRELOAD_NONE, &error);
-		if (error) {
-			g_warning ("ERROR : %s\n", error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-		else
-			obj->priv->cxn = gconf_client_notify_add (obj->priv->client,
-								  BRASERO_SEARCH_ENTRY_HISTORY_KEY,
-								  (GConfClientNotifyFunc) brasero_search_entry_history_changed_cb,
-								  obj, 
-								  NULL,
-								  &error);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_SEARCH_ENTRY_HISTORY,
+	                           &value);
 
-		if (error) {
-			g_warning ("ERROR : %s\n", error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-
-		obj->priv->history = gconf_client_get_list (obj->priv->client,
-							    BRASERO_SEARCH_ENTRY_HISTORY_KEY,
-							    GCONF_VALUE_STRING,
-							    &error);
-
-		if (error) {
-			g_warning ("ERROR : %s\n", error->message);
-			g_error_free (error);
-		}
-		else if (obj->priv->history)
-			brasero_search_entry_set_history (obj);
-	}
-	else
-		g_warning ("ERROR : could not connect to GCONF.\n");
+	brasero_search_entry_set_history (obj, value);
+	g_strfreev (value);
 }
 
 static void
 brasero_search_entry_destroy (GtkObject *gtk_object)
 {
-	BraseroSearchEntry *cobj;
-
-	cobj = BRASERO_SEARCH_ENTRY (gtk_object);
-
-	/* release gconf client */
-	g_object_unref (cobj->priv->client);
-
 	GTK_OBJECT_CLASS (parent_class)->destroy (gtk_object);
 }
 
@@ -420,10 +353,6 @@ brasero_search_entry_finalize (GObject *object)
 
 	cobj = BRASERO_SEARCH_ENTRY (object);
 
-	g_slist_foreach (cobj->priv->history, (GFunc) g_free, NULL);
-	g_slist_free (cobj->priv->history);
-	cobj->priv->history = NULL;
-
 	if (cobj->priv->search_id) {
 		g_source_remove (cobj->priv->search_id);
 		cobj->priv->search_id = 0;
@@ -455,41 +384,6 @@ brasero_search_entry_category_clicked_cb (GtkWidget *button,
 	}
 }
 
-static void
-brasero_search_entry_history_changed_cb (GConfClient *client,
-					 guint cnx_id,
-					 GConfEntry *entry,
-					 BraseroSearchEntry *widget)
-{
-	GConfValue *value;
-	GSList *list = NULL, *iter;
-	const char *keywords;
-
-	/* a few checks */
-	value = gconf_entry_get_value (entry);
-	if (value->type != GCONF_VALUE_LIST)
-		return;
-
-	if (gconf_value_get_list_type (value) != GCONF_VALUE_STRING)
-		return;
-
-	/* clears up history */
-	g_slist_foreach (widget->priv->history, (GFunc) g_free, NULL);
-	g_slist_free (widget->priv->history);
-	widget->priv->history = NULL;
-
-	/* get the new history */
-	list = gconf_value_get_list (value);
-	for (iter = list; iter && g_slist_length (widget->priv->history) < BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS; iter = iter->next) {
-		value = (GConfValue *) iter->data;
-		keywords = gconf_value_get_string (value);
-		widget->priv->history = g_slist_append (widget->priv->history,
-							g_strdup (keywords));
-	}
-
-	brasero_search_entry_set_history (widget);
-}
-
 static void
 brasero_search_entry_button_clicked_cb (GtkButton *button,
 					BraseroSearchEntry *entry)
@@ -569,50 +463,33 @@ brasero_search_entry_activated (BraseroSearchEntry *entry,
 
 	if (!search_now) {
 		/* gtk_widget_set_sensitive (entry->priv->button, TRUE); */
-		entry->priv->search_id = g_timeout_add (2000,
-							(GSourceFunc) brasero_search_entry_activated_real,
-							entry);
+		entry->priv->search_id = g_timeout_add_seconds (2,
+								(GSourceFunc) brasero_search_entry_activated_real,
+								entry);
 	}
 	else
 		brasero_search_entry_check_keywords (entry);
 }
 
 static void
-brasero_search_entry_set_history (BraseroSearchEntry *entry)
+brasero_search_entry_set_history (BraseroSearchEntry *entry,
+                                  const gchar * const *history)
 {
 	int i;
-	GSList *iter;
 	GtkTreeIter row;
 	GtkListStore *store;
 
 	store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (entry->priv->combo)));
 	gtk_list_store_clear (GTK_LIST_STORE (store));
 
-	if (entry->priv->history == NULL)
-		return;
-
-	i = 0;
-	for (iter = entry->priv->history; iter && i < BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS; iter = iter->next) {
-		gtk_list_store_append (store, &row);
-		gtk_list_store_set (store, &row,
-				    BRASERO_SEARCH_ENTRY_DISPLAY_COL, iter->data,
-				    BRASERO_SEARCH_ENTRY_BACKGRD_COL, NULL,
-				    -1);
-		i ++;
-	}
-
-	if (iter) {
-		GSList *next;
-
-		next = iter->next;
-
-		/* if there are other items simply free them */
-		entry->priv->history = g_slist_remove_link (entry->priv->history, iter);
-		g_free (iter->data);
-		g_slist_free (iter);
-
-		g_slist_foreach (next, (GFunc) g_free, NULL);
-		g_slist_free (next);
+	if (history) {
+		for (i = 0; history [i] && i < BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS; i ++) {
+			gtk_list_store_append (store, &row);
+			gtk_list_store_set (store, &row,
+					    BRASERO_SEARCH_ENTRY_DISPLAY_COL, history [i],
+					    BRASERO_SEARCH_ENTRY_BACKGRD_COL, NULL,
+					    -1);
+		}
 	}
 
 	/* separator */
@@ -634,136 +511,138 @@ brasero_search_entry_set_history (BraseroSearchEntry *entry)
 static void
 brasero_search_entry_save_history (BraseroSearchEntry *entry)
 {
-	GError *error = NULL;
+	GtkTreeModel *model;
+	int num_children;
+	GtkTreeIter iter;
+	gchar **array;
+	int i = 0;
 
-	gconf_client_notify_remove (entry->priv->client, entry->priv->cxn);
-	gconf_client_set_list (entry->priv->client,
-			       BRASERO_SEARCH_ENTRY_HISTORY_KEY,
-			       GCONF_VALUE_STRING,
-			       entry->priv->history, &error);
-	if (error) {
-		g_warning ("ERROR : %s\n", error->message);
-		g_error_free (error);
-		error = NULL;
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (entry->priv->combo));
+	if (!gtk_tree_model_get_iter_first (model, &iter)) {
+		brasero_setting_set_value (brasero_setting_get_default (),
+					   BRASERO_SETTING_SEARCH_ENTRY_HISTORY,
+					   NULL);
+		return;
 	}
 
-	entry->priv->cxn = gconf_client_notify_add (entry->priv->client,
-						    BRASERO_SEARCH_ENTRY_HISTORY_KEY,
-						    (GConfClientNotifyFunc) brasero_search_entry_history_changed_cb,
-						    entry, NULL, &error);
-	if (error) {
-		g_warning ("ERROR : %s\n", error->message);
-		g_error_free (error);
-	}
+	/* NOTE: the last item is not to be included nor
+	 * the blank line should be included. Only
+	 * substract one to have an empty row in the
+	 * array. */
+	num_children = gtk_tree_model_iter_n_children (model, NULL);
+	array = g_new0 (gchar *, -- num_children);
+
+	do {
+		gchar *string;
+
+		string = NULL;
+		gtk_tree_model_get (model, &iter,
+		                    BRASERO_SEARCH_ENTRY_DISPLAY_COL, &string,
+		                    -1);
+
+		/* break on the blank line */
+		if (string == NULL)
+			break;
+
+		array [i++] = string;
+	} while (gtk_tree_model_iter_next (model, &iter));
+
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_SEARCH_ENTRY_HISTORY,
+	                           array);
+	g_strfreev (array);
 }
 
 static void
 brasero_search_entry_add_current_keyword_to_history (BraseroSearchEntry *entry)
 {
 	const char *keywords = NULL;
-	GSList *iter;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
 
 	/* we don't want to add static entry */
 	keywords =  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (entry->priv->combo)->child));
 	if (!keywords || !strcmp (keywords, _("All files")))
 		return;
 
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (entry->priv->combo));
+	if (!gtk_tree_model_get_iter_first (model, &iter))
+		return;
+
 	/* make sure the item is not already in the list
 	 * otherwise just move it up in first position */
-	for (iter = entry->priv->history; iter; iter = iter->next) {
-		if (!strcmp (keywords, (char *) iter->data)) {
-			keywords = iter->data;
-			entry->priv->history = g_slist_remove (entry->priv->history,
-							       keywords);
-			entry->priv->history = g_slist_prepend (entry->priv->history,
-								(char *) keywords);
+	do {
+		gchar *string;
+
+		string = NULL;
+		gtk_tree_model_get (model, &iter,
+		                    BRASERO_SEARCH_ENTRY_DISPLAY_COL, &string,
+		                    -1);
+
+		/* break when we reach the blank line */
+		if (!string)
+			break;
+
+		if (!strcmp (keywords, string)) {
+			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			                    BRASERO_SEARCH_ENTRY_DISPLAY_COL, string,
+			                    -1);
+			g_free (string);
 			goto end;
 		}
+
+		g_free (string);
+	} while (gtk_tree_model_iter_next (model, &iter));
+
+	/* Remember that in model we have the 10 items
+	 * a NULL one and the "All Files" one */
+	if (gtk_tree_model_iter_n_children (model, NULL) == BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS + 2) {
+		gtk_tree_model_iter_nth_child (model,
+		                               &iter,
+		                               NULL, 
+		                               BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS - 1);
+
+		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 	}
 
-	if (g_slist_length (entry->priv->history) == BRASERO_SEARCH_ENTRY_MAX_HISTORY_ITEMS) {
-		iter = g_slist_last (entry->priv->history);
-		entry->priv->history = g_slist_remove (entry->priv->history, iter);
-	}
+	gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+	                    BRASERO_SEARCH_ENTRY_DISPLAY_COL, keywords,
+	                    -1);
 
-	entry->priv->history = g_slist_prepend (entry->priv->history,
-						g_strdup (keywords));
+end:
 
-      end:
 	brasero_search_entry_save_history (entry);
-	brasero_search_entry_set_history (entry);
 }
 
-BeagleQuery *
-brasero_search_entry_get_query (BraseroSearchEntry *entry)
+gboolean
+brasero_search_entry_set_query (BraseroSearchEntry *entry,
+                                BraseroSearchEngine *search)
 {
-	BeagleQuery *query;
-	BeagleQueryPartOr *or_part;
-	BeagleQueryPartHuman *text;
+	BraseroSearchScope scope = BRASERO_SEARCH_SCOPE_ANY;
+	const gchar *keywords = NULL;
 
-	/* Not sure about all this */
-	query = beagle_query_new ();
+	if (strcmp (entry->priv->keywords, _("All files")))
+		keywords = entry->priv->keywords;
 
-	if (strcmp (entry->priv->keywords, _("All files"))) {
-		BeagleQueryPartHuman *text;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->documents)))
+		scope |= BRASERO_SEARCH_SCOPE_DOCUMENTS;
 
-		text = beagle_query_part_human_new ();
-		beagle_query_part_human_set_string (text, entry->priv->keywords);
-		beagle_query_part_set_logic (BEAGLE_QUERY_PART (text),
-					     BEAGLE_QUERY_PART_LOGIC_REQUIRED);
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->pictures)))
+		scope |= BRASERO_SEARCH_SCOPE_PICTURES;
 
-		beagle_query_add_part (query, BEAGLE_QUERY_PART (text));
-	}
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->music)))
+		scope |= BRASERO_SEARCH_SCOPE_MUSIC;
 
-	text = beagle_query_part_human_new ();
-	beagle_query_part_human_set_string (text, "type:File");
-	beagle_query_add_part (query, BEAGLE_QUERY_PART (text));
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->video)))
+		scope |= BRASERO_SEARCH_SCOPE_VIDEO;
 
-	or_part = beagle_query_part_or_new ();
-	
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->documents))) {
-		BeagleQueryPartProperty *filetype;
+	brasero_search_engine_new_query (search, keywords);
+	brasero_search_engine_set_query_scope (search, scope);
 
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "document");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->pictures))) {
-		BeagleQueryPartProperty *filetype;
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "image");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->music))) {
-		BeagleQueryPartProperty *filetype;
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "audio");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->video))) {
-		BeagleQueryPartProperty *filetype;
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "video");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	beagle_query_add_part (query, BEAGLE_QUERY_PART (or_part));
-
-	return query;
+	return TRUE;
 }
 
 void
@@ -788,4 +667,3 @@ brasero_search_entry_set_context (BraseroSearchEntry *self,
 	}
 }
 
-#endif /*BUILD_SEARCH*/
